# Form implementation generated from reading ui file '/home/joe/Projects/imagetopixel/airunner/src/airunner/pyqt/generate_form.ui'
#
# Created by: PyQt6 UI code generator 6.4.2
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        Form.resize(432, 1064)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Preferred, QtWidgets.QSizePolicy.Policy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Form.sizePolicy().hasHeightForWidth())
        Form.setSizePolicy(sizePolicy)
        Form.setMinimumSize(QtCore.QSize(100, 0))
        Form.setLayoutDirection(QtCore.Qt.LayoutDirection.LeftToRight)
        self.gridLayout_7 = QtWidgets.QGridLayout(Form)
        self.gridLayout_7.setContentsMargins(0, 0, 0, 0)
        self.gridLayout_7.setObjectName("gridLayout_7")
        self.scrollArea = QtWidgets.QScrollArea(parent=Form)
        self.scrollArea.setFrameShape(QtWidgets.QFrame.Shape.NoFrame)
        self.scrollArea.setFrameShadow(QtWidgets.QFrame.Shadow.Plain)
        self.scrollArea.setLineWidth(0)
        self.scrollArea.setWidgetResizable(True)
        self.scrollArea.setObjectName("scrollArea")
        self.scrollAreaWidgetContents_3 = QtWidgets.QWidget()
        self.scrollAreaWidgetContents_3.setGeometry(QtCore.QRect(0, 0, 432, 1064))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.scrollAreaWidgetContents_3.sizePolicy().hasHeightForWidth())
        self.scrollAreaWidgetContents_3.setSizePolicy(sizePolicy)
        self.scrollAreaWidgetContents_3.setObjectName("scrollAreaWidgetContents_3")
        self.gridLayout_4 = QtWidgets.QGridLayout(self.scrollAreaWidgetContents_3)
        self.gridLayout_4.setContentsMargins(5, 0, 5, 0)
        self.gridLayout_4.setObjectName("gridLayout_4")
        self.gridLayout_2 = QtWidgets.QGridLayout()
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.label = QtWidgets.QLabel(parent=self.scrollAreaWidgetContents_3)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        self.label.setFont(font)
        self.label.setObjectName("label")
        self.gridLayout_2.addWidget(self.label, 7, 0, 1, 1)
        self.controlnet_groupbox = QtWidgets.QGroupBox(parent=self.scrollAreaWidgetContents_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Preferred, QtWidgets.QSizePolicy.Policy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.controlnet_groupbox.sizePolicy().hasHeightForWidth())
        self.controlnet_groupbox.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        self.controlnet_groupbox.setFont(font)
        self.controlnet_groupbox.setObjectName("controlnet_groupbox")
        self.gridLayout_5 = QtWidgets.QGridLayout(self.controlnet_groupbox)
        self.gridLayout_5.setContentsMargins(-1, 6, 6, 6)
        self.gridLayout_5.setObjectName("gridLayout_5")
        self.controlnet_guidance_scale_slider = QtWidgets.QSlider(parent=self.controlnet_groupbox)
        self.controlnet_guidance_scale_slider.setMaximum(100)
        self.controlnet_guidance_scale_slider.setPageStep(1)
        self.controlnet_guidance_scale_slider.setProperty("value", 50)
        self.controlnet_guidance_scale_slider.setOrientation(QtCore.Qt.Orientation.Horizontal)
        self.controlnet_guidance_scale_slider.setObjectName("controlnet_guidance_scale_slider")
        self.gridLayout_5.addWidget(self.controlnet_guidance_scale_slider, 0, 0, 1, 1)
        self.controlnet_guidance_scale_spinbox = QtWidgets.QDoubleSpinBox(parent=self.controlnet_groupbox)
        self.controlnet_guidance_scale_spinbox.setMinimumSize(QtCore.QSize(75, 24))
        self.controlnet_guidance_scale_spinbox.setMaximumSize(QtCore.QSize(75, 16777215))
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(False)
        self.controlnet_guidance_scale_spinbox.setFont(font)
        self.controlnet_guidance_scale_spinbox.setMaximum(1.0)
        self.controlnet_guidance_scale_spinbox.setSingleStep(0.01)
        self.controlnet_guidance_scale_spinbox.setProperty("value", 0.5)
        self.controlnet_guidance_scale_spinbox.setObjectName("controlnet_guidance_scale_spinbox")
        self.gridLayout_5.addWidget(self.controlnet_guidance_scale_spinbox, 0, 1, 1, 1)
        self.gridLayout_2.addWidget(self.controlnet_groupbox, 14, 0, 1, 1)
        self.formLayout_6 = QtWidgets.QFormLayout()
        self.formLayout_6.setObjectName("formLayout_6")
        self.to_canvas_radio = QtWidgets.QRadioButton(parent=self.scrollAreaWidgetContents_3)
        font = QtGui.QFont()
        font.setPointSize(9)
        self.to_canvas_radio.setFont(font)
        self.to_canvas_radio.setChecked(True)
        self.to_canvas_radio.setObjectName("to_canvas_radio")
        self.formLayout_6.setWidget(0, QtWidgets.QFormLayout.ItemRole.LabelRole, self.to_canvas_radio)
        self.deterministic_radio = QtWidgets.QRadioButton(parent=self.scrollAreaWidgetContents_3)
        font = QtGui.QFont()
        font.setPointSize(9)
        self.deterministic_radio.setFont(font)
        self.deterministic_radio.setObjectName("deterministic_radio")
        self.formLayout_6.setWidget(0, QtWidgets.QFormLayout.ItemRole.FieldRole, self.deterministic_radio)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setSpacing(6)
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.generate = QtWidgets.QPushButton(parent=self.scrollAreaWidgetContents_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Minimum, QtWidgets.QSizePolicy.Policy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.generate.sizePolicy().hasHeightForWidth())
        self.generate.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(9)
        self.generate.setFont(font)
        self.generate.setObjectName("generate")
        self.horizontalLayout_3.addWidget(self.generate)
        self.progressBar = QtWidgets.QProgressBar(parent=self.scrollAreaWidgetContents_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.progressBar.sizePolicy().hasHeightForWidth())
        self.progressBar.setSizePolicy(sizePolicy)
        self.progressBar.setMaximumSize(QtCore.QSize(16777215, 25))
        font = QtGui.QFont()
        font.setPointSize(9)
        self.progressBar.setFont(font)
        self.progressBar.setProperty("value", 0)
        self.progressBar.setObjectName("progressBar")
        self.horizontalLayout_3.addWidget(self.progressBar)
        self.formLayout_6.setLayout(1, QtWidgets.QFormLayout.ItemRole.SpanningRole, self.horizontalLayout_3)
        self.gridLayout_2.addLayout(self.formLayout_6, 26, 0, 1, 1)
        self.samples_groupbox = QtWidgets.QGroupBox(parent=self.scrollAreaWidgetContents_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Preferred, QtWidgets.QSizePolicy.Policy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.samples_groupbox.sizePolicy().hasHeightForWidth())
        self.samples_groupbox.setSizePolicy(sizePolicy)
        self.samples_groupbox.setMinimumSize(QtCore.QSize(0, 60))
        self.samples_groupbox.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        self.samples_groupbox.setFont(font)
        self.samples_groupbox.setObjectName("samples_groupbox")
        self.gridLayout_11 = QtWidgets.QGridLayout(self.samples_groupbox)
        self.gridLayout_11.setContentsMargins(9, 6, 6, 6)
        self.gridLayout_11.setObjectName("gridLayout_11")
        self.samples_slider = QtWidgets.QSlider(parent=self.samples_groupbox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.MinimumExpanding, QtWidgets.QSizePolicy.Policy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.samples_slider.sizePolicy().hasHeightForWidth())
        self.samples_slider.setSizePolicy(sizePolicy)
        self.samples_slider.setMinimumSize(QtCore.QSize(50, 0))
        self.samples_slider.setMinimum(1)
        self.samples_slider.setMaximum(200)
        self.samples_slider.setOrientation(QtCore.Qt.Orientation.Horizontal)
        self.samples_slider.setObjectName("samples_slider")
        self.gridLayout_11.addWidget(self.samples_slider, 0, 0, 1, 1)
        self.samples_spinbox = QtWidgets.QSpinBox(parent=self.samples_groupbox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Minimum, QtWidgets.QSizePolicy.Policy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.samples_spinbox.sizePolicy().hasHeightForWidth())
        self.samples_spinbox.setSizePolicy(sizePolicy)
        self.samples_spinbox.setMinimumSize(QtCore.QSize(0, 24))
        self.samples_spinbox.setMaximumSize(QtCore.QSize(16777215, 24))
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        self.samples_spinbox.setFont(font)
        self.samples_spinbox.setMinimum(1)
        self.samples_spinbox.setMaximum(200)
        self.samples_spinbox.setObjectName("samples_spinbox")
        self.gridLayout_11.addWidget(self.samples_spinbox, 0, 1, 1, 1)
        self.interrupt_button = QtWidgets.QPushButton(parent=self.samples_groupbox)
        self.interrupt_button.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Minimum, QtWidgets.QSizePolicy.Policy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.interrupt_button.sizePolicy().hasHeightForWidth())
        self.interrupt_button.setSizePolicy(sizePolicy)
        self.interrupt_button.setMinimumSize(QtCore.QSize(0, 24))
        self.interrupt_button.setMaximumSize(QtCore.QSize(16777215, 24))
        self.interrupt_button.setObjectName("interrupt_button")
        self.gridLayout_11.addWidget(self.interrupt_button, 0, 2, 1, 1)
        self.gridLayout_2.addWidget(self.samples_groupbox, 22, 0, 1, 1)
        self.scheduler_dropdown = QtWidgets.QComboBox(parent=self.scrollAreaWidgetContents_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.MinimumExpanding, QtWidgets.QSizePolicy.Policy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.scheduler_dropdown.sizePolicy().hasHeightForWidth())
        self.scheduler_dropdown.setSizePolicy(sizePolicy)
        self.scheduler_dropdown.setMinimumSize(QtCore.QSize(50, 0))
        self.scheduler_dropdown.setMaximumSize(QtCore.QSize(16777215, 25))
        font = QtGui.QFont()
        font.setPointSize(9)
        self.scheduler_dropdown.setFont(font)
        self.scheduler_dropdown.setObjectName("scheduler_dropdown")
        self.gridLayout_2.addWidget(self.scheduler_dropdown, 10, 0, 1, 1)
        self.strength = QtWidgets.QGroupBox(parent=self.scrollAreaWidgetContents_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Preferred, QtWidgets.QSizePolicy.Policy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.strength.sizePolicy().hasHeightForWidth())
        self.strength.setSizePolicy(sizePolicy)
        self.strength.setMinimumSize(QtCore.QSize(0, 60))
        self.strength.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        self.strength.setFont(font)
        self.strength.setObjectName("strength")
        self.gridLayout_10 = QtWidgets.QGridLayout(self.strength)
        self.gridLayout_10.setContentsMargins(9, 6, 6, 6)
        self.gridLayout_10.setObjectName("gridLayout_10")
        self.strength_slider = QtWidgets.QSlider(parent=self.strength)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.MinimumExpanding, QtWidgets.QSizePolicy.Policy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.strength_slider.sizePolicy().hasHeightForWidth())
        self.strength_slider.setSizePolicy(sizePolicy)
        self.strength_slider.setMinimumSize(QtCore.QSize(50, 0))
        self.strength_slider.setMaximum(100)
        self.strength_slider.setOrientation(QtCore.Qt.Orientation.Horizontal)
        self.strength_slider.setObjectName("strength_slider")
        self.gridLayout_10.addWidget(self.strength_slider, 0, 0, 1, 1)
        self.strength_spinbox = QtWidgets.QDoubleSpinBox(parent=self.strength)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Maximum, QtWidgets.QSizePolicy.Policy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.strength_spinbox.sizePolicy().hasHeightForWidth())
        self.strength_spinbox.setSizePolicy(sizePolicy)
        self.strength_spinbox.setMinimumSize(QtCore.QSize(75, 24))
        self.strength_spinbox.setMaximumSize(QtCore.QSize(75, 24))
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(False)
        self.strength_spinbox.setFont(font)
        self.strength_spinbox.setAlignment(QtCore.Qt.AlignmentFlag.AlignLeading|QtCore.Qt.AlignmentFlag.AlignLeft|QtCore.Qt.AlignmentFlag.AlignVCenter)
        self.strength_spinbox.setMaximum(100.0)
        self.strength_spinbox.setSingleStep(0.01)
        self.strength_spinbox.setObjectName("strength_spinbox")
        self.gridLayout_10.addWidget(self.strength_spinbox, 0, 1, 1, 1)
        self.gridLayout_2.addWidget(self.strength, 20, 0, 1, 1)
        self.prompt = QtWidgets.QPlainTextEdit(parent=self.scrollAreaWidgetContents_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.MinimumExpanding, QtWidgets.QSizePolicy.Policy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.prompt.sizePolicy().hasHeightForWidth())
        self.prompt.setSizePolicy(sizePolicy)
        self.prompt.setMinimumSize(QtCore.QSize(50, 75))
        self.prompt.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.prompt.setFont(font)
        self.prompt.setFrameShadow(QtWidgets.QFrame.Shadow.Sunken)
        self.prompt.setObjectName("prompt")
        self.gridLayout_2.addWidget(self.prompt, 3, 0, 1, 1)
        self.downscale_settings = QtWidgets.QGridLayout()
        self.downscale_settings.setObjectName("downscale_settings")
        self.downscale_settings_sizes = QtWidgets.QVBoxLayout()
        self.downscale_settings_sizes.setObjectName("downscale_settings_sizes")
        self.downscale_settings_radiobuttons = QtWidgets.QVBoxLayout()
        self.downscale_settings_radiobuttons.setObjectName("downscale_settings_radiobuttons")
        self.full_image_radiobutton = QtWidgets.QRadioButton(parent=self.scrollAreaWidgetContents_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.MinimumExpanding, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.full_image_radiobutton.sizePolicy().hasHeightForWidth())
        self.full_image_radiobutton.setSizePolicy(sizePolicy)
        self.full_image_radiobutton.setMinimumSize(QtCore.QSize(75, 0))
        font = QtGui.QFont()
        font.setPointSize(9)
        self.full_image_radiobutton.setFont(font)
        self.full_image_radiobutton.setObjectName("full_image_radiobutton")
        self.downscale_settings_radiobuttons.addWidget(self.full_image_radiobutton)
        self.active_grid_radiobutton = QtWidgets.QRadioButton(parent=self.scrollAreaWidgetContents_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.MinimumExpanding, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.active_grid_radiobutton.sizePolicy().hasHeightForWidth())
        self.active_grid_radiobutton.setSizePolicy(sizePolicy)
        self.active_grid_radiobutton.setMinimumSize(QtCore.QSize(75, 0))
        font = QtGui.QFont()
        font.setPointSize(9)
        self.active_grid_radiobutton.setFont(font)
        self.active_grid_radiobutton.setObjectName("active_grid_radiobutton")
        self.downscale_settings_radiobuttons.addWidget(self.active_grid_radiobutton)
        self.downscale_settings_sizes.addLayout(self.downscale_settings_radiobuttons)
        self.downscale_label = QtWidgets.QLabel(parent=self.scrollAreaWidgetContents_3)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        self.downscale_label.setFont(font)
        self.downscale_label.setObjectName("downscale_label")
        self.downscale_settings_sizes.addWidget(self.downscale_label)
        self.downscale_amount_container = QtWidgets.QHBoxLayout()
        self.downscale_amount_container.setObjectName("downscale_amount_container")
        self.downscale_spinbox = QtWidgets.QSpinBox(parent=self.scrollAreaWidgetContents_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Maximum, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.downscale_spinbox.sizePolicy().hasHeightForWidth())
        self.downscale_spinbox.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(9)
        self.downscale_spinbox.setFont(font)
        self.downscale_spinbox.setMaximum(12)
        self.downscale_spinbox.setObjectName("downscale_spinbox")
        self.downscale_amount_container.addWidget(self.downscale_spinbox)
        self.final_size_label = QtWidgets.QLabel(parent=self.scrollAreaWidgetContents_3)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(False)
        self.final_size_label.setFont(font)
        self.final_size_label.setObjectName("final_size_label")
        self.downscale_amount_container.addWidget(self.final_size_label)
        self.final_size = QtWidgets.QLabel(parent=self.scrollAreaWidgetContents_3)
        font = QtGui.QFont()
        font.setPointSize(9)
        self.final_size.setFont(font)
        self.final_size.setObjectName("final_size")
        self.downscale_amount_container.addWidget(self.final_size)
        self.downscale_settings_sizes.addLayout(self.downscale_amount_container)
        self.downscale_settings.addLayout(self.downscale_settings_sizes, 0, 0, 1, 1)
        self.gridLayout_2.addLayout(self.downscale_settings, 25, 0, 1, 1)
        self.groupBox_24 = QtWidgets.QGroupBox(parent=self.scrollAreaWidgetContents_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Preferred, QtWidgets.QSizePolicy.Policy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_24.sizePolicy().hasHeightForWidth())
        self.groupBox_24.setSizePolicy(sizePolicy)
        self.groupBox_24.setMinimumSize(QtCore.QSize(75, 60))
        self.groupBox_24.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        self.groupBox_24.setFont(font)
        self.groupBox_24.setObjectName("groupBox_24")
        self.gridLayout_12 = QtWidgets.QGridLayout(self.groupBox_24)
        self.gridLayout_12.setContentsMargins(9, 9, 9, 9)
        self.gridLayout_12.setObjectName("gridLayout_12")
        self.seed = QtWidgets.QTextEdit(parent=self.groupBox_24)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.MinimumExpanding, QtWidgets.QSizePolicy.Policy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.seed.sizePolicy().hasHeightForWidth())
        self.seed.setSizePolicy(sizePolicy)
        self.seed.setMinimumSize(QtCore.QSize(50, 24))
        self.seed.setMaximumSize(QtCore.QSize(16777215, 24))
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        self.seed.setFont(font)
        self.seed.setObjectName("seed")
        self.gridLayout_12.addWidget(self.seed, 0, 0, 1, 1)
        self.random_checkbox = QtWidgets.QCheckBox(parent=self.groupBox_24)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Minimum, QtWidgets.QSizePolicy.Policy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.random_checkbox.sizePolicy().hasHeightForWidth())
        self.random_checkbox.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        self.random_checkbox.setFont(font)
        self.random_checkbox.setObjectName("random_checkbox")
        self.gridLayout_12.addWidget(self.random_checkbox, 0, 1, 1, 1)
        self.gridLayout_2.addWidget(self.groupBox_24, 21, 0, 1, 1)
        self.scheduler_label = QtWidgets.QLabel(parent=self.scrollAreaWidgetContents_3)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        self.scheduler_label.setFont(font)
        self.scheduler_label.setObjectName("scheduler_label")
        self.gridLayout_2.addWidget(self.scheduler_label, 9, 0, 1, 1)
        self.groupBox_21 = QtWidgets.QGroupBox(parent=self.scrollAreaWidgetContents_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.MinimumExpanding, QtWidgets.QSizePolicy.Policy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_21.sizePolicy().hasHeightForWidth())
        self.groupBox_21.setSizePolicy(sizePolicy)
        self.groupBox_21.setMinimumSize(QtCore.QSize(75, 60))
        self.groupBox_21.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        self.groupBox_21.setFont(font)
        self.groupBox_21.setAlignment(QtCore.Qt.AlignmentFlag.AlignLeading|QtCore.Qt.AlignmentFlag.AlignLeft|QtCore.Qt.AlignmentFlag.AlignVCenter)
        self.groupBox_21.setObjectName("groupBox_21")
        self.gridLayout_6 = QtWidgets.QGridLayout(self.groupBox_21)
        self.gridLayout_6.setContentsMargins(9, 6, 6, 6)
        self.gridLayout_6.setObjectName("gridLayout_6")
        self.steps_slider = QtWidgets.QSlider(parent=self.groupBox_21)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.MinimumExpanding, QtWidgets.QSizePolicy.Policy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.steps_slider.sizePolicy().hasHeightForWidth())
        self.steps_slider.setSizePolicy(sizePolicy)
        self.steps_slider.setMinimumSize(QtCore.QSize(50, 0))
        self.steps_slider.setMinimum(1)
        self.steps_slider.setMaximum(200)
        self.steps_slider.setOrientation(QtCore.Qt.Orientation.Horizontal)
        self.steps_slider.setObjectName("steps_slider")
        self.gridLayout_6.addWidget(self.steps_slider, 0, 0, 1, 1)
        self.steps_spinbox = QtWidgets.QSpinBox(parent=self.groupBox_21)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.MinimumExpanding, QtWidgets.QSizePolicy.Policy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.steps_spinbox.sizePolicy().hasHeightForWidth())
        self.steps_spinbox.setSizePolicy(sizePolicy)
        self.steps_spinbox.setMinimumSize(QtCore.QSize(75, 24))
        self.steps_spinbox.setMaximumSize(QtCore.QSize(75, 24))
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(False)
        self.steps_spinbox.setFont(font)
        self.steps_spinbox.setMinimum(1)
        self.steps_spinbox.setMaximum(200)
        self.steps_spinbox.setObjectName("steps_spinbox")
        self.gridLayout_6.addWidget(self.steps_spinbox, 0, 1, 1, 1)
        self.gridLayout_2.addWidget(self.groupBox_21, 15, 0, 1, 1)
        self.scale_box = QtWidgets.QGroupBox(parent=self.scrollAreaWidgetContents_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Preferred, QtWidgets.QSizePolicy.Policy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.scale_box.sizePolicy().hasHeightForWidth())
        self.scale_box.setSizePolicy(sizePolicy)
        self.scale_box.setMinimumSize(QtCore.QSize(0, 60))
        self.scale_box.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        self.scale_box.setFont(font)
        self.scale_box.setFlat(False)
        self.scale_box.setCheckable(False)
        self.scale_box.setObjectName("scale_box")
        self.gridLayout_8 = QtWidgets.QGridLayout(self.scale_box)
        self.gridLayout_8.setContentsMargins(9, 6, 6, 6)
        self.gridLayout_8.setObjectName("gridLayout_8")
        self.scale_slider = QtWidgets.QSlider(parent=self.scale_box)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.MinimumExpanding, QtWidgets.QSizePolicy.Policy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.scale_slider.sizePolicy().hasHeightForWidth())
        self.scale_slider.setSizePolicy(sizePolicy)
        self.scale_slider.setMinimumSize(QtCore.QSize(50, 0))
        self.scale_slider.setMaximum(10000)
        self.scale_slider.setOrientation(QtCore.Qt.Orientation.Horizontal)
        self.scale_slider.setObjectName("scale_slider")
        self.gridLayout_8.addWidget(self.scale_slider, 0, 0, 1, 1)
        self.scale_spinbox = QtWidgets.QDoubleSpinBox(parent=self.scale_box)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Maximum, QtWidgets.QSizePolicy.Policy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.scale_spinbox.sizePolicy().hasHeightForWidth())
        self.scale_spinbox.setSizePolicy(sizePolicy)
        self.scale_spinbox.setMinimumSize(QtCore.QSize(75, 24))
        self.scale_spinbox.setMaximumSize(QtCore.QSize(75, 24))
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(False)
        self.scale_spinbox.setFont(font)
        self.scale_spinbox.setMaximum(100.0)
        self.scale_spinbox.setSingleStep(0.01)
        self.scale_spinbox.setObjectName("scale_spinbox")
        self.gridLayout_8.addWidget(self.scale_spinbox, 0, 1, 1, 1)
        self.gridLayout_2.addWidget(self.scale_box, 18, 0, 1, 1)
        self.negative_prompt = QtWidgets.QPlainTextEdit(parent=self.scrollAreaWidgetContents_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.MinimumExpanding, QtWidgets.QSizePolicy.Policy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.negative_prompt.sizePolicy().hasHeightForWidth())
        self.negative_prompt.setSizePolicy(sizePolicy)
        self.negative_prompt.setMinimumSize(QtCore.QSize(50, 75))
        self.negative_prompt.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.negative_prompt.setFont(font)
        self.negative_prompt.setObjectName("negative_prompt")
        self.gridLayout_2.addWidget(self.negative_prompt, 5, 0, 1, 1)
        self.model_dropdown = QtWidgets.QComboBox(parent=self.scrollAreaWidgetContents_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.MinimumExpanding, QtWidgets.QSizePolicy.Policy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.model_dropdown.sizePolicy().hasHeightForWidth())
        self.model_dropdown.setSizePolicy(sizePolicy)
        self.model_dropdown.setMinimumSize(QtCore.QSize(50, 0))
        self.model_dropdown.setMaximumSize(QtCore.QSize(16777215, 25))
        font = QtGui.QFont()
        font.setPointSize(9)
        self.model_dropdown.setFont(font)
        self.model_dropdown.setObjectName("model_dropdown")
        self.gridLayout_2.addWidget(self.model_dropdown, 8, 0, 1, 1)
        self.label_5 = QtWidgets.QLabel(parent=self.scrollAreaWidgetContents_3)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        self.label_5.setFont(font)
        self.label_5.setObjectName("label_5")
        self.gridLayout_2.addWidget(self.label_5, 4, 0, 1, 1)
        self.horizontalLayout_9 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_9.setObjectName("horizontalLayout_9")
        self.controlnet_label = QtWidgets.QLabel(parent=self.scrollAreaWidgetContents_3)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        self.controlnet_label.setFont(font)
        self.controlnet_label.setObjectName("controlnet_label")
        self.horizontalLayout_9.addWidget(self.controlnet_label)
        self.enable_controlnet_checkbox = QtWidgets.QCheckBox(parent=self.scrollAreaWidgetContents_3)
        font = QtGui.QFont()
        font.setPointSize(8)
        font.setBold(True)
        self.enable_controlnet_checkbox.setFont(font)
        self.enable_controlnet_checkbox.setLayoutDirection(QtCore.Qt.LayoutDirection.LeftToRight)
        self.enable_controlnet_checkbox.setObjectName("enable_controlnet_checkbox")
        self.horizontalLayout_9.addWidget(self.enable_controlnet_checkbox, 0, QtCore.Qt.AlignmentFlag.AlignRight)
        self.gridLayout_2.addLayout(self.horizontalLayout_9, 11, 0, 1, 1)
        self.controlnet_dropdown = QtWidgets.QComboBox(parent=self.scrollAreaWidgetContents_3)
        self.controlnet_dropdown.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.MinimumExpanding, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.controlnet_dropdown.sizePolicy().hasHeightForWidth())
        self.controlnet_dropdown.setSizePolicy(sizePolicy)
        self.controlnet_dropdown.setMinimumSize(QtCore.QSize(50, 0))
        font = QtGui.QFont()
        font.setPointSize(9)
        self.controlnet_dropdown.setFont(font)
        self.controlnet_dropdown.setObjectName("controlnet_dropdown")
        self.gridLayout_2.addWidget(self.controlnet_dropdown, 13, 0, 1, 1)
        self.image_scale_box = QtWidgets.QGroupBox(parent=self.scrollAreaWidgetContents_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Preferred, QtWidgets.QSizePolicy.Policy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.image_scale_box.sizePolicy().hasHeightForWidth())
        self.image_scale_box.setSizePolicy(sizePolicy)
        self.image_scale_box.setMinimumSize(QtCore.QSize(75, 60))
        self.image_scale_box.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        self.image_scale_box.setFont(font)
        self.image_scale_box.setObjectName("image_scale_box")
        self.gridLayout_9 = QtWidgets.QGridLayout(self.image_scale_box)
        self.gridLayout_9.setContentsMargins(9, 6, 6, 6)
        self.gridLayout_9.setObjectName("gridLayout_9")
        self.image_scale_slider = QtWidgets.QSlider(parent=self.image_scale_box)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.MinimumExpanding, QtWidgets.QSizePolicy.Policy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.image_scale_slider.sizePolicy().hasHeightForWidth())
        self.image_scale_slider.setSizePolicy(sizePolicy)
        self.image_scale_slider.setMinimumSize(QtCore.QSize(50, 0))
        self.image_scale_slider.setMaximum(10000)
        self.image_scale_slider.setOrientation(QtCore.Qt.Orientation.Horizontal)
        self.image_scale_slider.setObjectName("image_scale_slider")
        self.gridLayout_9.addWidget(self.image_scale_slider, 0, 0, 1, 1)
        self.image_scale_spinbox = QtWidgets.QDoubleSpinBox(parent=self.image_scale_box)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Maximum, QtWidgets.QSizePolicy.Policy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.image_scale_spinbox.sizePolicy().hasHeightForWidth())
        self.image_scale_spinbox.setSizePolicy(sizePolicy)
        self.image_scale_spinbox.setMinimumSize(QtCore.QSize(75, 24))
        self.image_scale_spinbox.setMaximumSize(QtCore.QSize(75, 24))
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(False)
        self.image_scale_spinbox.setFont(font)
        self.image_scale_spinbox.setMaximum(100.0)
        self.image_scale_spinbox.setSingleStep(0.01)
        self.image_scale_spinbox.setObjectName("image_scale_spinbox")
        self.gridLayout_9.addWidget(self.image_scale_spinbox, 0, 1, 1, 1)
        self.gridLayout_2.addWidget(self.image_scale_box, 19, 0, 1, 1)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.label_4 = QtWidgets.QLabel(parent=self.scrollAreaWidgetContents_3)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        self.label_4.setFont(font)
        self.label_4.setObjectName("label_4")
        self.horizontalLayout_2.addWidget(self.label_4)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem)
        self.use_prompt_builder_checkbox = QtWidgets.QCheckBox(parent=self.scrollAreaWidgetContents_3)
        font = QtGui.QFont()
        font.setPointSize(8)
        font.setBold(True)
        self.use_prompt_builder_checkbox.setFont(font)
        self.use_prompt_builder_checkbox.setLayoutDirection(QtCore.Qt.LayoutDirection.LeftToRight)
        self.use_prompt_builder_checkbox.setObjectName("use_prompt_builder_checkbox")
        self.horizontalLayout_2.addWidget(self.use_prompt_builder_checkbox)
        self.gridLayout_2.addLayout(self.horizontalLayout_2, 1, 0, 1, 1)
        self.gridLayout_4.addLayout(self.gridLayout_2, 4, 0, 1, 1)
        self.scrollArea.setWidget(self.scrollAreaWidgetContents_3)
        self.gridLayout_7.addWidget(self.scrollArea, 0, 0, 1, 1)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(_translate("Form", "Form"))
        self.label.setText(_translate("Form", "Model"))
        self.controlnet_groupbox.setTitle(_translate("Form", "Controlnet Scale"))
        self.to_canvas_radio.setText(_translate("Form", "Single"))
        self.deterministic_radio.setText(_translate("Form", "Batch"))
        self.generate.setText(_translate("Form", "Generate"))
        self.samples_groupbox.setTitle(_translate("Form", "Samples"))
        self.interrupt_button.setText(_translate("Form", "Interrupt"))
        self.strength.setTitle(_translate("Form", "Strength"))
        self.full_image_radiobutton.setText(_translate("Form", "Full image"))
        self.active_grid_radiobutton.setText(_translate("Form", "Active grid"))
        self.downscale_label.setText(_translate("Form", "Downscale N times before upscale"))
        self.final_size_label.setText(_translate("Form", "output size"))
        self.final_size.setText(_translate("Form", "1920x1920"))
        self.groupBox_24.setTitle(_translate("Form", "Seed"))
        self.random_checkbox.setText(_translate("Form", "Random"))
        self.scheduler_label.setText(_translate("Form", "Scheduler"))
        self.groupBox_21.setTitle(_translate("Form", "Steps"))
        self.scale_box.setTitle(_translate("Form", "Scale"))
        self.label_5.setText(_translate("Form", "Negative prompt"))
        self.controlnet_label.setText(_translate("Form", "Controlnet"))
        self.enable_controlnet_checkbox.setText(_translate("Form", "Use Controlnet"))
        self.image_scale_box.setTitle(_translate("Form", "Image Scale"))
        self.label_4.setText(_translate("Form", "Prompt"))
        self.use_prompt_builder_checkbox.setText(_translate("Form", "Use Prompt Builder"))
