# Form implementation generated from reading ui file '/home/joe/Projects/imagetopixel/airunner/src/airunner/pyqt/model_merger.ui'
#
# Created by: PyQt6 UI code generator 6.4.2
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_Dialog(object):
    def setupUi(self, Dialog):
        Dialog.setObjectName("Dialog")
        Dialog.resize(400, 630)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Preferred, QtWidgets.QSizePolicy.Policy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Dialog.sizePolicy().hasHeightForWidth())
        Dialog.setSizePolicy(sizePolicy)
        Dialog.setMinimumSize(QtCore.QSize(1, 630))
        self.gridLayout = QtWidgets.QGridLayout(Dialog)
        self.gridLayout.setObjectName("gridLayout")
        self.addModel_button = QtWidgets.QPushButton(parent=Dialog)
        self.addModel_button.setObjectName("addModel_button")
        self.gridLayout.addWidget(self.addModel_button, 7, 0, 1, 1)
        self.model_types = QtWidgets.QComboBox(parent=Dialog)
        self.model_types.setObjectName("model_types")
        self.gridLayout.addWidget(self.model_types, 1, 0, 1, 1)
        self.label_4 = QtWidgets.QLabel(parent=Dialog)
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_4.setFont(font)
        self.label_4.setObjectName("label_4")
        self.gridLayout.addWidget(self.label_4, 9, 0, 1, 1)
        self.label_3 = QtWidgets.QLabel(parent=Dialog)
        font = QtGui.QFont()
        font.setBold(True)
        self.label_3.setFont(font)
        self.label_3.setObjectName("label_3")
        self.gridLayout.addWidget(self.label_3, 2, 0, 1, 1)
        self.label_6 = QtWidgets.QLabel(parent=Dialog)
        font = QtGui.QFont()
        font.setBold(True)
        self.label_6.setFont(font)
        self.label_6.setObjectName("label_6")
        self.gridLayout.addWidget(self.label_6, 8, 0, 1, 1)
        self.base_models = QtWidgets.QComboBox(parent=Dialog)
        self.base_models.setObjectName("base_models")
        self.gridLayout.addWidget(self.base_models, 3, 0, 1, 1)
        self.label = QtWidgets.QLabel(parent=Dialog)
        font = QtGui.QFont()
        font.setBold(True)
        self.label.setFont(font)
        self.label.setObjectName("label")
        self.gridLayout.addWidget(self.label, 0, 0, 1, 1)
        self.models = QtWidgets.QTabWidget(parent=Dialog)
        self.models.setObjectName("models")
        self.gridLayout.addWidget(self.models, 5, 0, 1, 1)
        self.model_name = QtWidgets.QLineEdit(parent=Dialog)
        self.model_name.setObjectName("model_name")
        self.gridLayout.addWidget(self.model_name, 10, 0, 1, 1)
        self.label_5 = QtWidgets.QLabel(parent=Dialog)
        font = QtGui.QFont()
        font.setBold(True)
        self.label_5.setFont(font)
        self.label_5.setObjectName("label_5")
        self.gridLayout.addWidget(self.label_5, 4, 0, 1, 1)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.merge_button = QtWidgets.QPushButton(parent=Dialog)
        self.merge_button.setObjectName("merge_button")
        self.horizontalLayout.addWidget(self.merge_button)
        self.progressBar = QtWidgets.QProgressBar(parent=Dialog)
        self.progressBar.setProperty("value", 0)
        self.progressBar.setObjectName("progressBar")
        self.horizontalLayout.addWidget(self.progressBar)
        self.gridLayout.addLayout(self.horizontalLayout, 11, 0, 1, 1)

        self.retranslateUi(Dialog)
        self.models.setCurrentIndex(-1)
        QtCore.QMetaObject.connectSlotsByName(Dialog)

    def retranslateUi(self, Dialog):
        _translate = QtCore.QCoreApplication.translate
        Dialog.setWindowTitle(_translate("Dialog", "Model Merger"))
        self.addModel_button.setText(_translate("Dialog", "Add model"))
        self.label_4.setText(_translate("Dialog", "Save the merged model as this name"))
        self.label_3.setText(_translate("Dialog", "Base model"))
        self.label_6.setText(_translate("Dialog", "Model Name"))
        self.label.setText(_translate("Dialog", "Model Type"))
        self.label_5.setText(_translate("Dialog", "Models to merge into base model"))
        self.merge_button.setText(_translate("Dialog", "Merge"))
