# Form implementation generated from reading ui file '/home/joe/Projects/imagetopixel/airunner/src/airunner/pyqt/widgets/layer_container_widget.ui'
#
# Created by: PyQt6 UI code generator 6.4.2
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        Form.resize(277, 318)
        self.gridLayout = QtWidgets.QGridLayout(Form)
        self.gridLayout.setContentsMargins(0, 0, 0, 0)
        self.gridLayout.setSpacing(0)
        self.gridLayout.setObjectName("gridLayout")
        self.layers = QtWidgets.QScrollArea(parent=Form)
        self.layers.setStyleSheet("border-radius: 0px")
        self.layers.setFrameShape(QtWidgets.QFrame.Shape.StyledPanel)
        self.layers.setFrameShadow(QtWidgets.QFrame.Shadow.Sunken)
        self.layers.setWidgetResizable(True)
        self.layers.setAlignment(QtCore.Qt.AlignmentFlag.AlignLeading|QtCore.Qt.AlignmentFlag.AlignLeft|QtCore.Qt.AlignmentFlag.AlignTop)
        self.layers.setObjectName("layers")
        self.scrollAreaWidgetContents = QtWidgets.QWidget()
        self.scrollAreaWidgetContents.setGeometry(QtCore.QRect(0, 0, 277, 278))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Preferred, QtWidgets.QSizePolicy.Policy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.scrollAreaWidgetContents.sizePolicy().hasHeightForWidth())
        self.scrollAreaWidgetContents.setSizePolicy(sizePolicy)
        self.scrollAreaWidgetContents.setObjectName("scrollAreaWidgetContents")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.scrollAreaWidgetContents)
        self.verticalLayout.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout.setSpacing(0)
        self.verticalLayout.setObjectName("verticalLayout")
        self.layers.setWidget(self.scrollAreaWidgetContents)
        self.gridLayout.addWidget(self.layers, 0, 0, 1, 1)
        self.horizontalWidget = QtWidgets.QWidget(parent=Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.horizontalWidget.sizePolicy().hasHeightForWidth())
        self.horizontalWidget.setSizePolicy(sizePolicy)
        self.horizontalWidget.setLayoutDirection(QtCore.Qt.LayoutDirection.LeftToRight)
        self.horizontalWidget.setObjectName("horizontalWidget")
        self.horizontalLayout_8 = QtWidgets.QHBoxLayout(self.horizontalWidget)
        self.horizontalLayout_8.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_8.setSpacing(0)
        self.horizontalLayout_8.setObjectName("horizontalLayout_8")
        self.new_layer_button = QtWidgets.QPushButton(parent=self.horizontalWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Fixed, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.new_layer_button.sizePolicy().hasHeightForWidth())
        self.new_layer_button.setSizePolicy(sizePolicy)
        self.new_layer_button.setMinimumSize(QtCore.QSize(40, 40))
        self.new_layer_button.setStyleSheet("border-color: rgb(61, 56, 70);")
        self.new_layer_button.setText("")
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap("/home/joe/Projects/imagetopixel/airunner/src/airunner/pyqt/widgets/../../src/icons/035-new.png"), QtGui.QIcon.Mode.Normal, QtGui.QIcon.State.Off)
        self.new_layer_button.setIcon(icon)
        self.new_layer_button.setIconSize(QtCore.QSize(24, 24))
        self.new_layer_button.setFlat(True)
        self.new_layer_button.setObjectName("new_layer_button")
        self.horizontalLayout_8.addWidget(self.new_layer_button)
        self.layer_up_button = QtWidgets.QPushButton(parent=self.horizontalWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Minimum, QtWidgets.QSizePolicy.Policy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.layer_up_button.sizePolicy().hasHeightForWidth())
        self.layer_up_button.setSizePolicy(sizePolicy)
        self.layer_up_button.setMinimumSize(QtCore.QSize(40, 40))
        self.layer_up_button.setStyleSheet("border-color: rgb(61, 56, 70);")
        self.layer_up_button.setText("")
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap("/home/joe/Projects/imagetopixel/airunner/src/airunner/pyqt/widgets/../../src/icons/041-up-arrow.png"), QtGui.QIcon.Mode.Normal, QtGui.QIcon.State.Off)
        self.layer_up_button.setIcon(icon1)
        self.layer_up_button.setIconSize(QtCore.QSize(24, 24))
        self.layer_up_button.setFlat(True)
        self.layer_up_button.setObjectName("layer_up_button")
        self.horizontalLayout_8.addWidget(self.layer_up_button)
        self.layer_down_button = QtWidgets.QPushButton(parent=self.horizontalWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Minimum, QtWidgets.QSizePolicy.Policy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.layer_down_button.sizePolicy().hasHeightForWidth())
        self.layer_down_button.setSizePolicy(sizePolicy)
        self.layer_down_button.setMinimumSize(QtCore.QSize(40, 40))
        self.layer_down_button.setStyleSheet("border-color: rgb(61, 56, 70);")
        self.layer_down_button.setText("")
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap("/home/joe/Projects/imagetopixel/airunner/src/airunner/pyqt/widgets/../../src/icons/042-down-arrow.png"), QtGui.QIcon.Mode.Normal, QtGui.QIcon.State.Off)
        self.layer_down_button.setIcon(icon2)
        self.layer_down_button.setIconSize(QtCore.QSize(24, 24))
        self.layer_down_button.setFlat(True)
        self.layer_down_button.setObjectName("layer_down_button")
        self.horizontalLayout_8.addWidget(self.layer_down_button)
        spacerItem = QtWidgets.QSpacerItem(500, 20, QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Minimum)
        self.horizontalLayout_8.addItem(spacerItem)
        self.delete_layer_button = QtWidgets.QPushButton(parent=self.horizontalWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Fixed, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.delete_layer_button.sizePolicy().hasHeightForWidth())
        self.delete_layer_button.setSizePolicy(sizePolicy)
        self.delete_layer_button.setMinimumSize(QtCore.QSize(40, 40))
        self.delete_layer_button.setStyleSheet("border-color: rgb(61, 56, 70);")
        self.delete_layer_button.setText("")
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap("/home/joe/Projects/imagetopixel/airunner/src/airunner/pyqt/widgets/../../src/icons/006-trash.png"), QtGui.QIcon.Mode.Normal, QtGui.QIcon.State.Off)
        self.delete_layer_button.setIcon(icon3)
        self.delete_layer_button.setIconSize(QtCore.QSize(24, 24))
        self.delete_layer_button.setFlat(True)
        self.delete_layer_button.setObjectName("delete_layer_button")
        self.horizontalLayout_8.addWidget(self.delete_layer_button)
        self.gridLayout.addWidget(self.horizontalWidget, 1, 0, 1, 1)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(_translate("Form", "Form"))
        self.new_layer_button.setToolTip(_translate("Form", "Create a new layer"))
